class NoBalance(Exception):
  def __init__(self, message: str, status_code: int):
    self.message = message
    self.status_code = status_code
    
  def __str__(self):
    return "({}) {}".format(self.message, str(self.status_code))  
    
class HCaptchaError(Exception):
  def __init__(self, message: str, status_code: int):
    self.message = message
    self.status_code = status_code
    
  def __str__(self):
    return "({}) {}".format(self.message, str(self.status_code))


import requests, time
from .exceptions import *


class HCaptcha:  # check dc
    # kk

    def __init__(self, client_key: str, beta: bool = False) -> None:

        self.client_key = client_key
        self.session = requests.Session()
        self.basesite = "https://api.capsolver.com/createTask"
        self.retrys = 0

    def create_task(self, url: str, sitekey: str, isInvisble: bool = False):
        headers = {"Content-Type": "application/json"}

        json = {
            "clientKey": self.client_key,
            "task": {
                "type": "HCaptchaTaskProxyLess",
                "websiteURL": url,
                "websiteKey": sitekey,
                "isInvisible": isInvisble,
                "enterprisePayload": {"rqdata": ""},
                "proxy": "",
                "userAgent": "",
            },
        }

        self.response = self.session.post(self.basesite, headers=headers, json=json)

        if self.response.status_code == 400:
            raise HCaptchaError(self.response.text, self.response.status_code)

        return self.response.json()["taskId"]

    def join_task_together(self, taskId: str):

        self.task_id = taskId

        headers = {"Content-Type": "application/json"}
        json = {"clientKey": self.client_key, "taskId": self.task_id}
        while True:
            response = self.session.post("https://api.capsolver.com/getTaskResult", json=json, headers=headers).json()

            if response["status"] == "processing":
                time.sleep(1)
                self.retrys += 1
                continue
            elif response["status"] == "ready":
                return response["solution"]["gRecaptchaResponse"]
                break
            elif self.retrys == 90:  # go to discord
                raise HCaptchaError("MAX RETRYS", 400)



from setuptools import setup, find_packages
 
classifiers = [
  'Development Status :: 5 - Production/Stable',
  'Intended Audience :: Education',
  'Operating System :: Microsoft :: Windows :: Windows 10',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]
 
setup(
  name='py-capsolver',
  version='0.0.3',
  description='capsolver wrappeer',
  url='',
  author='Slotth',
  author_email='slotth@outlook.com',
  classifiers=classifiers,
  keywords='capsolver', 
  packages=find_packages(),
  install_requires=[''] 
)


import requests

class CAPSOLVER:
    def __init__(self, client_key: str):
        self.client_key = client_key
        self.session = requests.Session()

    def checkbalance(self):
        headers = {"Content-Type": "application/json"}
        json = {"clientKey": self.client_key}
      
        response = self.session.post("https://api.capsolver.com/getBalance", headers=headers, json=json).json()
        return response
